# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import veriservice.veriservice_pb2 as veriservice__pb2


class VeriServiceStub(object):
  """protoc -I veriservice/ veriservice/veriservice.proto --go_out=plugins=grpc:veriservice
  The Customer service definition.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetKnn = channel.unary_unary(
        '/veriservice.VeriService/GetKnn',
        request_serializer=veriservice__pb2.KnnRequest.SerializeToString,
        response_deserializer=veriservice__pb2.KnnResponse.FromString,
        )
    self.Insert = channel.unary_unary(
        '/veriservice.VeriService/Insert',
        request_serializer=veriservice__pb2.InsertionRequest.SerializeToString,
        response_deserializer=veriservice__pb2.InsertionResponse.FromString,
        )
    self.Join = channel.unary_unary(
        '/veriservice.VeriService/Join',
        request_serializer=veriservice__pb2.JoinRequest.SerializeToString,
        response_deserializer=veriservice__pb2.JoinResponse.FromString,
        )
    self.ExchangeServices = channel.unary_unary(
        '/veriservice.VeriService/ExchangeServices',
        request_serializer=veriservice__pb2.ServiceMessage.SerializeToString,
        response_deserializer=veriservice__pb2.ServiceMessage.FromString,
        )
    self.ExchangePeers = channel.unary_unary(
        '/veriservice.VeriService/ExchangePeers',
        request_serializer=veriservice__pb2.PeerMessage.SerializeToString,
        response_deserializer=veriservice__pb2.PeerMessage.FromString,
        )
    self.GetLocalData = channel.unary_stream(
        '/veriservice.VeriService/GetLocalData',
        request_serializer=veriservice__pb2.GetLocalDataRequest.SerializeToString,
        response_deserializer=veriservice__pb2.Feature.FromString,
        )


class VeriServiceServicer(object):
  """protoc -I veriservice/ veriservice/veriservice.proto --go_out=plugins=grpc:veriservice
  The Customer service definition.
  """

  def GetKnn(self, request, context):
    """Get all Customers with filter - A server-to-client streaming RPC.
    rpc GetCustomers(CustomerFilter) returns (stream CustomerRequest) {}
    Create a new Customer - A simple RPC
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Insert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Join(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ExchangeServices(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ExchangePeers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLocalData(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_VeriServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetKnn': grpc.unary_unary_rpc_method_handler(
          servicer.GetKnn,
          request_deserializer=veriservice__pb2.KnnRequest.FromString,
          response_serializer=veriservice__pb2.KnnResponse.SerializeToString,
      ),
      'Insert': grpc.unary_unary_rpc_method_handler(
          servicer.Insert,
          request_deserializer=veriservice__pb2.InsertionRequest.FromString,
          response_serializer=veriservice__pb2.InsertionResponse.SerializeToString,
      ),
      'Join': grpc.unary_unary_rpc_method_handler(
          servicer.Join,
          request_deserializer=veriservice__pb2.JoinRequest.FromString,
          response_serializer=veriservice__pb2.JoinResponse.SerializeToString,
      ),
      'ExchangeServices': grpc.unary_unary_rpc_method_handler(
          servicer.ExchangeServices,
          request_deserializer=veriservice__pb2.ServiceMessage.FromString,
          response_serializer=veriservice__pb2.ServiceMessage.SerializeToString,
      ),
      'ExchangePeers': grpc.unary_unary_rpc_method_handler(
          servicer.ExchangePeers,
          request_deserializer=veriservice__pb2.PeerMessage.FromString,
          response_serializer=veriservice__pb2.PeerMessage.SerializeToString,
      ),
      'GetLocalData': grpc.unary_stream_rpc_method_handler(
          servicer.GetLocalData,
          request_deserializer=veriservice__pb2.GetLocalDataRequest.FromString,
          response_serializer=veriservice__pb2.Feature.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'veriservice.VeriService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
